from math_utils import math_utils
from string_utils import string_utils
from image_utils import image_utils
from list_utils import list_utils


class elan:
    # math
    math = math_utils()
    # string
    string = string_utils()
    # list
    list = list_utils()
    # image
    image = image_utils()


if __name__ == "__main__":
    elan()




class list_utils:
    def __init__(self):
        pass

    def reverse(self, list):
        return list[::-1]   
    
    def sort(self, list):
        return sorted(list)
    
    def reverse(self, list):
        return list[::-1]   
   
    def unique(self, list):
        return list(set(list))
    
    
    
if __name__ == "__main__":
    list_utils()
    




from math_utils import *
from string_utils import *
from list_utils import *
from image_utils import *

__all__ = ["math_utils", "string_utils", "list_utils", "image_utils"]


__version__ = "0.1.0"
__author__ = "Efekan Nefesoğlu"
__license__ = "MIT"


import cv2

class image_utils:
    def __init__(self):
        pass

    def to_grayscale(self, image_path):
        image = cv2.imread(image_path)
        gray_image = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
        return gray_image

    def resize(self, image_path, width, height):
        image = cv2.imread(image_path)
        resized_image = cv2.resize(image, (width, height))
        return resized_image

    def rotate(self, image_path, angle):
        image = cv2.imread(image_path)
        (h, w) = image.shape[:2]
        center = (w // 2, h // 2)
        M = cv2.getRotationMatrix2D(center, angle, 1.0)
        rotated_image = cv2.warpAffine(image, M, (w, h))
        return rotated_image

if __name__ == "__main__":
    image_utils() 


from setuptools import setup, find_packages

setup(
    name="elan",  # PyPI'de görünecek paket adı
    version="0.1.9",
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    install_requires=[],  # Bağımlılıklar buraya eklenebilir (örn: numpy, pandas)
    author="Efekan Nefesoğlu",
    author_email="efekan8190nefesogeu@gmail.com",
    description="ElanLibs",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/efekannn5/ElanLibs",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
